<?php
/**
 * Unirgy LLC
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the EULA
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.unirgy.com/LICENSE-M1.txt
 *
 * @category   Unirgy
 * @package    Unirgy_DropshipLocator
 * @copyright  Copyright (c) 2008-2009 Unirgy LLC (http://www.unirgy.com)
 * @license    http:///www.unirgy.com/LICENSE-M1.txt
 */

class Unirgy_DropshipLocator_Model_Observer
{
    public function udropship_vendor_save_after($observer)
    {
        $vendor = $observer->getEvent()->getVendor();
        if ($vendor->getCurrentlyInSaveAfter()) {
            return;
        }

        $location = Mage::getModel('ustorelocator/location')->load($vendor->getMainLocationId());
        $setMainLocation = false;
        // if main location was deleted or never set
        if (!$location->getId()) {
            // try to find a existing one or create a new one
            $location->load($vendor->getId(), 'udropship_vendor');
            $setMainLocation = true;
        }

        $location->addData(array(
            'title' => $vendor->getVendorName(),
            'address' => '',
            'address_display' => $vendor->getFormatedAddress(),
            'phone' => $vendor->getTelephone(),
            'udropship_vendor' => $vendor->getId(),
            'recalculate' => true,
        ))->save();

        if ($setMainLocation) {
            $vendor->setCurrentlyInSaveAfter(true)
                ->setMainLocationId($location->getId())->save()
                ->unsCurrentlyInSaveAfter();
        }
    }

    public function ustorelocator_adminhtml_grid_prepare_columns($observer)
    {
        $block = $observer->getEvent()->getBlock();

        $block->addColumn('udropship_vendor', array(
            'index'     => 'udropship_vendor',
            'header'    => Mage::helper('udropship')->__('Dropship Vendor'),
            'type'      => 'options',
            'options'   => Mage::getSingleton('udropship/source')->setPath('vendors')->toOptionHash(),
            'filter' => 'udropship/vendor_gridColumnFilter'
        ));
    }

    public function ustorelocator_adminhtml_edit_prepare_form($observer)
    {
        $form = $observer->getEvent()->getForm();
        $fieldset = $form->getElement('location_form');

        $fieldset->addField('udropship_vendor', 'select', array(
            'name'      => 'udropship_vendor',
            'label'     => Mage::helper('udropship')->__('Dropship Vendor'),
            'options'   => Mage::getSingleton('udropship/source')->setPath('vendors')->toOptionHash(true),
        ));
    }

    public function udropship_adminhtml_vendor_edit_prepare_form($observer)
    {
        $id = $observer->getEvent()->getId();
        $form = $observer->getEvent()->getForm();
        $fieldset = $form->getElement('vendor_form');
        
        $locations = Mage::getModel('ustorelocator/location')->getCollection()
            ->addFieldToFilter('udropship_vendor', $id);

        if ($locations->count()) {
            $options = array();
            foreach ($locations as $item) {
                $options[$item->getId()] = $item->getTitle().' - '.$item->getAddress();
            }
            $fieldset->addField('main_location_id', 'select', array(
                'name'      => 'main_location_id',
                'label'     => Mage::helper('udropship')->__('Main Geo Location'),
                'options'   => $options,
            ));
        }
    }
}
